==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Farchive_mail.0.7-1.4.0.tar.gz: archive_mail/includes/formats/maildir.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Archive Mail
    Version ........ 0.7
    Purpose ........ Allows you to download your email in a compressed archive

*******************************************************************************/


               $body_a = sqimap_run_command($imapConnection, "FETCH $id RFC822",true, $response, $readmessage, $uid_support);
               if ($response == 'OK') {
                  $c++;
                  if ($sort == 6 || ($thread_sort_messages || $allow_server_sort))
                     $k = $i + $start_index;
                  else
                     $k = $id - 1;
                  $seen = $msgs[$k]['FLAG_SEEN'];
                  if (!$seen)
                     sqimap_toggle_flag($imapConnection, $id, '\\Seen',false,true);
                  sqimap_toggle_flag($imapConnection, $id, '\\Archived',true,true);
                  $email = $msgs[$k]['FROM'][0][0];
                  $email = trim($email);
                  $email = str_replace(' ', '-', $email);
                  $email = str_replace(chr(9), '-', $email);
                  $timestamp = $msgs[$k]['TIME_STAMP'];
                  if (date('d',$timestamp) < 10)
                     $mdate = date('D M  j H:i:s Y', $timestamp);
                  else
                     $mdate = date('D M d H:i:s Y', $timestamp);
                  if ($archiveattachments == 0) {
                     $boundry = '';
                     $cb = count($body_a);
                     for ($v = 0; $v < $cb; $v++) {
                        if ($boundry != '') {
                           if (trim($body_a[$v]) == $boundry) {
                              if (!strpos($body_a[$v+1]," text/")) {
                                 $q = 1;
                                 $body_a[$v] = '';
                                 while ($v < $cb && $q) {
                                    $v++;
                                    if (trim($body_a[$v]) == $eboundry)
                                       $q = 0;
                                    if ($q != 0)
                                       unset($body_a[$v]);
                                 }
                              }
                           }
                        }else{
                           if (strpos($body_a[$v], 'boundary') !== false) {
                              $boundry = "--" . substr(trim($body_a[$v]),10,strlen(trim($body_a[$v]))-11);
                              $eboundry = $boundry . "--";
                           }
                        }
                     }
                  }
                  array_shift($body_a);
                  $body = implode('', $body_a);
                  srand();
                  $filename = time() . '.' . rand(1,100000) . '.' . 'localhost';
                  $dir = 'cur';
                  if (!$seen)
                     $dir = 'new';
                  $zipfile -> addFile($body, "$dir/$filename");
               }

?>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Farchive_mail.0.8-1.4.2.tar.gz: archive_mail/includes/formats/maildir.php <==
<?php
/*******************************************************************************

    Author ......... Jimmy Conner
    Contact ........ jimmy@advcs.org
    Home Site ...... http://www.advcs.org/
    Program ........ Archive Mail
    Version ........ 0.8
    Purpose ........ Allows you to download your email in a compressed archive

*******************************************************************************/


               $body_a = sqimap_run_command($imapConnection, "FETCH $id RFC822",true, $response, $readmessage, $uid_support);
               if ($response == 'OK') {
                  $c++;
                  $k = $i + $start_index;
                  $seen = $msgs[$k]['FLAG_SEEN'];
                  if (!$seen)
                     sqimap_toggle_flag($imapConnection, $id, '\\Seen',false,true);
                  $email = $msgs[$k]['FROM'];
                  if (strpos($email, '<') !== false)
                     $email = substr($email, strpos($email, '<')+1, strpos($email, '>') - strpos($email, '<')-1);
                  $email = trim($email);
                  $email = str_replace(' ', '-', $email);
                  $email = str_replace(chr(9), '-', $email);
                  $timestamp = $msgs[$k]['TIME_STAMP'];
                  if (date('d',$timestamp) < 10)
                     $mdate = date('D M  j H:i:s Y', $timestamp);
                  else
                     $mdate = date('D M d H:i:s Y', $timestamp);
                  if ($archiveattachments == 0) {
                     $boundry = '';
                     $cb = count($body_a);
                     for ($v = 0; $v < $cb; $v++) {
                        if ($boundry != '') {
                           if (trim($body_a[$v]) == $boundry) {
                              if (!strpos($body_a[$v+1]," text/")) {
                                 $q = 1;
                                 $body_a[$v] = '';
                                 while ($v < $cb && $q) {
                                    $v++;
                                    if (trim($body_a[$v]) == $eboundry)
                                       $q = 0;
                                    if ($q != 0)
                                       unset($body_a[$v]);
                                 }
                              }
                           }
                        }else{
                           if (strpos($body_a[$v], 'boundary') !== false) {
                              $boundry = "--" . substr(trim($body_a[$v]),10,strlen(trim($body_a[$v]))-11);
                              $eboundry = $boundry . "--";
                           }
                        }
                     }
                  }
                  array_shift($body_a);
                  $body = implode('', $body_a);
                  srand();
                  $filename = time() . '.' . rand(1,100000) . '.' . 'localhost';
                  $dir = 'cur';
                  if (!$seen)
                     $dir = 'new';
                  $zipfile -> addFile($body, "$dir/$filename");
               }

?>
